@@ -108,14 +108,18 @@ from .populationstrategy import (
     AdaptivePopulationSize,
     ConstantPopulationSize)
 from . import visualization
+from . import settings
 from .version import __version__  # noqa: F401
 
+
+# Set log level
 try:
     loglevel = os.environ['ABC_LOG_LEVEL'].upper()
 except KeyError:
     loglevel = 'INFO'
-
 logging.basicConfig(level=loglevel)
 
+# Set number of threads e.g. for numpy. as pyabc uses parallelization on its
+#  own, this is a safer default.
 if 'OMP_NUM_THREADS' not in os.environ:
     os.environ['OMP_NUM_THREADS'] = '1'
