@@ -222,6 +222,12 @@ class AdaptivePNormDistance(PNormDistance):
         if self.adaptive:
             sampler.sample_factory.record_rejected = True
 
+    def requires_calibration(self) -> bool:
+        return self.initial_weights is None
+
+    def is_adaptive(self) -> bool:
+        return self.adaptive
+
     def initialize(self,
                    t: int,
                    get_all_sum_stats: Callable[[], List[dict]],
@@ -233,7 +239,7 @@ class AdaptivePNormDistance(PNormDistance):
         self.x_0 = x_0
 
         # initial weights pre-defined
-        if self.initial_weights is not None:
+        if not self.requires_calibration():
             self.weights[t] = self.initial_weights
             return
 
@@ -249,7 +255,7 @@ class AdaptivePNormDistance(PNormDistance):
         """
         Update weights.
         """
-        if not self.adaptive:
+        if not self.is_adaptive():
             return False
 
         # execute function
@@ -407,6 +413,12 @@ class AggregatedDistance(Distance):
         self.weights = weights
         self.factors = factors
 
+    def requires_calibration(self) -> bool:
+        return any(d.requires_calibration() for d in self.distances)
+
+    def is_adaptive(self) -> bool:
+        return any(d.is_adaptive() for d in self.distances)
+
     def initialize(
             self,
             t: int,
@@ -552,6 +564,14 @@ class AdaptiveAggregatedDistance(AggregatedDistance):
         self.scale_function = scale_function
         self.log_file = log_file
 
+    def requires_calibration(self) -> bool:
+        return (self.initial_weights is None
+                or any(d.requires_calibration() for d in self.distances))
+
+    def is_adaptive(self) -> bool:
+        return (self.adaptive
+                or any(d.is_adaptive() for d in self.distances))
+
     def initialize(self,
                    t: int,
                    get_all_sum_stats: Callable[[], List[dict]],
@@ -716,6 +736,9 @@ class PCADistance(DistanceWithMeasureList):
         self._whitening_transformation_matrix = (
             v.dot(np.diag(1. / np.sqrt(w))).dot(v.T))
 
+    def requires_calibration(self) -> bool:
+        return True
+
     def initialize(self,
                    t: int,
                    get_all_sum_stats: Callable[[], List[dict]],
@@ -812,6 +835,9 @@ class RangeEstimatorDistance(DistanceWithMeasureList):
                               - self.lower(measures[measure])
                               for measure in self.measures_to_use}
 
+    def requires_calibration(self) -> bool:
+        return True
+
     def initialize(self,
                    t: int,
                    get_all_sum_stats: Callable[[], List[dict]],
