@@ -38,7 +38,7 @@ def internal_docstring_warning(f):
     indent_level = len(first_line) - len(first_line.lstrip())
     indent = " " * indent_level
     warning = (
-        "\n" + indent +
+        "\n\n" + indent +
         "**Note.** This function is called by the :class:`pyabc.ABCSMC` "
         "class internally. "
         "You should most likely not find it necessary to call "
@@ -110,20 +110,17 @@ class History:
 
     Attributes
     ----------
-
     db: str
         SQLalchemy database identifier. For a relative path use the
         template "sqlite:///file.db", for an absolute path
         "sqlite:////path/to/file.db", and for an in-memory database
         "sqlite://".
-
     stores_sum_stats: bool, optional (default = True)
         Whether to store summary statistics to the database. Note: this
         is True by default, and should be set to False only for testing
         purposes (i.e. to speed up the writing to the file system),
         as it can not be guaranteed that all methods of pyabc work
         correctly if the summary statistics are not stored.
-
     id: int
         The id of the ABCSMC analysis that is currently in use.
         If there are analyses in the database already, this defaults
@@ -178,13 +175,11 @@ class History:
 
         Returns
         -------
-
         db_size: int, str
             Size of the SQLite database in MB.
             Currently this only works for SQLite databases.
 
             Returns an error string if the DB size cannot be calculated.
-
         """
         try:
             return os.path.getsize(self.db_file()) / 10 ** 6
@@ -272,17 +267,14 @@ class History:
 
         Parameters
         ----------
-
         m: int, optional (default = 0)
             Model index.
-
         t: int, optional (default = self.max_t)
             Population index.
             If t is not specified, then the last population is returned.
 
         Returns
         -------
-
         df, w: pandas.DataFrame, np.ndarray
             * df: a DataFrame of parameters
             * w: are the weights associated with each parameter
@@ -352,7 +344,6 @@ class History:
 
         Returns
         -------
-
         all_populations: pd.DataFrame
             DataFrame with population info
         """
@@ -369,48 +360,47 @@ class History:
 
     @with_session
     @internal_docstring_warning
-    def store_initial_data(self, ground_truth_model: int, options: dict,
+    def store_initial_data(self,
+                           ground_truth_model: int,
+                           options: dict,
                            observed_summary_statistics: dict,
                            ground_truth_parameter: dict,
                            model_names: List[str],
                            distance_function_json_str: str,
                            eps_function_json_str: str,
-                           population_strategy_json_str: str):
+                           population_strategy_json_str: str,
+                           start_time: datetime.datetime = None) -> None:
         """
         Store the initial configuration data.
 
         Parameters
         ----------
-
-        ground_truth_model: int
+        ground_truth_model:
             Index of the ground truth model.
-
-        options: dict
+        options:
             Of ABC metadata.
-
-        observed_summary_statistics: dict
+        observed_summary_statistics:
             The measured summary statistics.
-
-        ground_truth_parameter: dict
+        ground_truth_parameter:
             The ground truth parameters.
-
-        model_names: List
+        model_names:
             A list of model names.
-
-        distance_function_json_str: str
+        distance_function_json_str:
             The distance function represented as json string.
-
-        eps_function_json_str: str
+        eps_function_json_str:
             The epsilon represented as json string.
-
-        population_strategy_json_str: str
+        population_strategy_json_str:
             The population strategy represented as json string.
-
+        start_time:
+            Start time of the analysis.
         """
+        if start_time is None:
+            start_time = datetime.datetime.now()
+
         # create a new ABCSMC analysis object
         abcsmc = ABCSMC(
             json_parameters=str(options),
-            start_time=datetime.datetime.now(),
+            start_time=start_time,
             git_hash=git_hash(),
             distance_function=distance_function_json_str,
             epsilon_function=eps_function_json_str,
@@ -429,7 +419,7 @@ class History:
             ground_truth_parameter, model_names)
 
         # log
-        logger.info("Start {}".format(abcsmc))
+        logger.info(f"Start {abcsmc.start_info()}")
 
     @with_session
     @internal_docstring_warning
@@ -443,6 +433,7 @@ class History:
         and in particular some ground truth values.
 
         For the parameters, see store_initial_data.
+
         """
         # extract analysis object
         abcsmc = (self._session.query(ABCSMC)
@@ -495,30 +486,29 @@ class History:
 
     @with_session
     @internal_docstring_warning
-    def update_nr_samples(self, t: int = PRE_TIME, nr_samples: int = 0):
-        """
-        Update the number of samples used in iteration `t`. The default
-        time of `PRE_TIME` implies an update of the number of samples
-        used in calibration.
+    def update_after_calibration(
+            self,  nr_samples: int, end_time: datetime.datetime):
+        """Update after the calibration iteration.
+        In particular set time and number of samples.
+        Update the number of samples used in iteration `t`.
 
         Parameters
         ----------
-
-        t: int, optional (default = -1)
-            Time to update for.
-        nr_samples: int, optional (default = 0)
+        nr_samples:
             Number of samples reported.
-
+        end_time:
+            End time of the calibration iteration.
         """
         # extract population
         population = (self._session.query(Population)
                       .join(ABCSMC)
                       .filter(ABCSMC.id == self.id)
-                      .filter(Population.t == t)
+                      .filter(Population.t == History.PRE_TIME)
                       .one())
 
         # update samples number
         population.nr_samples = nr_samples
+        population.population_end_time = end_time
 
         # commit changes
         self._session.commit()
@@ -530,7 +520,6 @@ class History:
 
         Returns
         -------
-
         sum_stats_dct: dict
             The observed summary statistics.
         """
@@ -557,7 +546,6 @@ class History:
 
         Returns
         -------
-
         nr_sim: int
             Total nr of sample attempts for the ABC run.
         """
@@ -599,17 +587,23 @@ class History:
 
     @with_session
     @internal_docstring_warning
-    def done(self):
-        """
-        Close database sessions and store end time of population.
+    def done(self, end_time: datetime.datetime = None):
         """
+        Close database sessions and store end time of the analysis.
 
-        abc_smc_simulation = (self._session.query(ABCSMC)
-                              .filter(ABCSMC.id == self.id)
-                              .one())
-        abc_smc_simulation.end_time = datetime.datetime.now()
+        Parameters
+        ----------
+        end_time:
+            End time of the analysis.
+        """
+        if end_time is None:
+            end_time = datetime.datetime.now()
+
+        abcsmc = (self._session.query(ABCSMC)
+                  .filter(ABCSMC.id == self.id).one())
+        abcsmc.end_time = end_time
         self._session.commit()
-        logger.info("Done {}".format(abc_smc_simulation))
+        logger.info(f"Done {abcsmc.end_info()}")
 
     @with_session
     def _save_to_population_db(self,
@@ -703,22 +697,16 @@ class History:
 
         Parameters
         ----------
-
         t: int
             Population number.
-
         current_epsilon: float
             Current epsilon value.
-
         population: Population
             List of sampled particles.
-
         nr_simulations: int
             The number of model evaluations for this population.
-
         model_names: list
             The model names.
-
         """
         store = population.to_dict()
         model_probabilities = population.get_model_probabilities()
@@ -777,13 +765,11 @@ class History:
 
         Parameters
         ----------
-
         t: int, optional (default = self.max_t)
             Population index.
 
         Returns
         -------
-
         nr_alive: int >= 0 or None
             Number of models still alive.
             None is for the last population
@@ -807,14 +793,12 @@ class History:
 
         Parameters
         ----------
-
         t: int, optional (default = self.max_t)
             Population index.
             If t is None, the last population is selected.
 
         Returns
         -------
-
         df_weighted: pd.DataFrame
             Weighted distances.
             The dataframe has column "w" for the weights
@@ -862,7 +846,6 @@ class History:
 
         Returns
         -------
-
         nr_particles_per_population: pd.DataFrame
             A pandas DataFrame containing the number
             of particles for each population.
@@ -905,16 +888,13 @@ class History:
 
         Parameters
         ----------
-
         m: int, optional (default = 0)
             Model index.
-
         t: int, optional (default = self.max_t)
             Population index.
 
         Returns
         -------
-
         w, sum_stats: np.ndarray, list
             * w: the weights associated with the summary statistics
             * sum_stats: list of summary statistics
@@ -954,15 +934,13 @@ class History:
 
         Parameters
         ----------
-
         t: int, optional (default = self.max_t)
             Population index.
             If t is None, the latest population is selected.
 
         Returns
         -------
-
-        (weights, sum_stats): (List[float], List[dict])
+        weights, sum_stats:
             In the same order in the first array the weights (multiplied by
             the model probabilities), and tin the second array the summary
             statistics.
@@ -1008,7 +986,6 @@ class History:
 
         Parameters
         ----------
-
         t: int, optional (default = self.max_t)
             The population index.
         """
@@ -1078,7 +1055,7 @@ class History:
 
     @with_session
     def get_population_strategy(self):
-        """
+        """Get information on the population size strategy.
 
         Returns
         -------
@@ -1099,16 +1076,13 @@ class History:
 
         Parameters
         ----------
-
         m: int or None, optional (default = None)
             The model to query. If omitted, all models are returned.
-
         t: int or str, optional (default = "last")
             Can be "last" or "all", or a population index (i.e. an int).
             In case of "all", all populations are returned.
             If "last", only the last population is returned, for an int value
             only the corresponding population at that time index.
-
         tidy: bool, optional
             If True, try to return a tidy DataFrame, where the individual
             parameters and summary statistics are pivoted.
@@ -1117,7 +1091,6 @@ class History:
 
         Returns
         -------
-
         full_population: DataFrame
         """
         query = (self._session.query(Population.t,
