@@ -17,7 +17,10 @@ from .sample import (
     plot_sample_numbers,
     plot_total_sample_numbers,
     plot_sample_numbers_trajectory,
-    plot_acceptance_rates_trajectory)
+    plot_acceptance_rates_trajectory,
+    plot_lookahead_evaluations,
+    plot_lookahead_final_acceptance_fractions,
+    plot_lookahead_acceptance_rates)
 from .epsilon import (
     plot_epsilons)
 from .histogram import (
@@ -37,3 +40,9 @@ from .effective_sample_size import (
 from .data import (
     plot_data_callback,
     plot_data_default)
+from .walltime import (
+    plot_total_walltime,
+    plot_walltime,
+    plot_walltime_lowlevel,
+    plot_eps_walltime,
+    plot_eps_walltime_lowlevel)
